==> incountry-3.4.0-py2.py3-none-any.whl: incountry/secret_key_accessor.py <==
from pydantic import ValidationError

from .exceptions import StorageClientException
from .validation import validate_model
from .validation.utils import get_formatted_validation_error
from .models import (
    SecretsDataForDefaultEncryption,
    SecretsDataForCustomEncryption,
    SecretKeyAccessor as SecretKeyAccessorModel,
)


class SecretKeyAccessor:
    DEFAULT_VERSION = 0

    @validate_model(SecretKeyAccessorModel)
    def __init__(self, accessor_function):
        self._accessor_function = accessor_function
        self._custom_encryption_keys_enabled = False

    def enable_custom_encryption_keys(self):
        self._custom_encryption_keys_enabled = True

    def get_secrets_data(self):
        try:
            secrets_data = self._accessor_function()
        except Exception as e:
            raise StorageClientException("Failed to retrieve secret keys data") from e

        if not isinstance(secrets_data, (str, bytes, dict)):
            raise StorageClientException(
                f"SecretKeyAccessor validation error: "
                f"accessor_function - should return either str, bytes or secrets_data dict"
            )

        return secrets_data

    def get_secrets_raw(self):
        secrets_data = self.get_secrets_data()

        if isinstance(secrets_data, str):
            return (secrets_data.encode("utf-8"), SecretKeyAccessor.DEFAULT_VERSION, False)

        if isinstance(secrets_data, bytes):
            return (secrets_data, SecretKeyAccessor.DEFAULT_VERSION, False)

        model = (
            SecretsDataForCustomEncryption if self._custom_encryption_keys_enabled else SecretsDataForDefaultEncryption
        )

        try:
            return model.validate(secrets_data).dict()
        except ValidationError as e:
            raise StorageClientException(
                f"SecretKeyAccessor validation error: {get_formatted_validation_error(e)}", e
            ) from None

    def validate(self):
        self.get_secrets_raw()

    def get_secret(self, version=None, is_for_custom_encryption=False):
        if version is not None and not isinstance(version, int):
            raise StorageClientException("Invalid secret version requested. Version should be of type `int`")

        secrets_data = self.get_secrets_raw()
        if isinstance(secrets_data, tuple):
            return secrets_data

        version_to_search = version if version is not None else secrets_data.get("currentVersion")

        for secret_data in secrets_data.get("secrets"):
            if secret_data.get("version") == version_to_search:
                is_key = secret_data.get("isKey", False)
                secret = secret_data.get("secret")
                if is_for_custom_encryption and not secret_data.get("isForCustomEncryption", False):
                    raise StorageClientException("Requested secret for custom encryption. Got a regular one instead.")
                return (secret, version_to_search, is_key)

        raise StorageClientException("Secret not found for version {}".format(version_to_search))

==> incountry-5.0.0-py2.py3-none-any.whl: incountry/secret_key_accessor.py <==
from typing import Callable

from pydantic import BaseModel, ValidationError

from .exceptions import SecretsProviderException, SecretsValidationException
from .validation import validate_model
from .validation.utils import get_formatted_validation_error


class SecretKeyAccessorModel(BaseModel):
    accessor_function: Callable


class SecretKeyAccessor:
    DEFAULT_VERSION = 0

    @validate_model(SecretKeyAccessorModel)
    def __init__(self, accessor_function):
        self._accessor_function = accessor_function
        self._custom_encryption_keys_enabled = False

    def enable_custom_encryption_keys(self):
        self._custom_encryption_keys_enabled = True

    def get_secrets_data(self):
        try:
            secrets_data = self._accessor_function()
        except Exception as e:
            raise SecretsProviderException("Failed to retrieve secret keys data") from e

        if not isinstance(secrets_data, (str, bytes, dict)):
            raise SecretsValidationException(
                f"SecretKeyAccessor validation error: "
                f"accessor_function - should return either str, bytes or secrets_data dict"
            )

        return secrets_data

    def get_secrets_raw(self):
        secrets_data = self.get_secrets_data()

        if isinstance(secrets_data, str):
            return (secrets_data.encode("utf-8"), SecretKeyAccessor.DEFAULT_VERSION, False)

        if isinstance(secrets_data, bytes):
            return (secrets_data, SecretKeyAccessor.DEFAULT_VERSION, False)

        from .models import (
            SecretsDataForDefaultEncryption,
            SecretsDataForCustomEncryption,
        )

        model = (
            SecretsDataForCustomEncryption if self._custom_encryption_keys_enabled else SecretsDataForDefaultEncryption
        )

        try:
            return model.validate(secrets_data).dict()
        except ValidationError as e:
            raise SecretsValidationException(
                f"SecretKeyAccessor validation error: {get_formatted_validation_error(e)}", e
            ) from None

    def validate(self):
        self.get_secrets_raw()

    def get_secret(self, version=None, is_for_custom_encryption=False):
        if version is not None and not isinstance(version, int):
            raise SecretsValidationException("Invalid secret version requested. Version should be of type `int`")

        secrets_data = self.get_secrets_raw()
        if isinstance(secrets_data, tuple):
            return secrets_data

        version_to_search = version if version is not None else secrets_data.get("currentVersion")

        for secret_data in secrets_data.get("secrets"):
            if secret_data.get("version") == version_to_search:
                is_key = secret_data.get("isKey", False)
                secret = secret_data.get("secret")
                if is_for_custom_encryption and not secret_data.get("isForCustomEncryption", False):
                    raise SecretsValidationException(
                        "Requested secret for custom encryption. Got a regular one instead."
                    )
                return (secret, version_to_search, is_key)

        raise SecretsValidationException("Secret not found for version {}".format(version_to_search))
